#!/usr/bin/env python
# coding: utf-8

import setuptools
from setuptools import setup
with open("README1.md", "r", encoding="UTF-8") as fh:
    long_description = fh.read()
setup(
    name='robotgpt-interpreter',
    version='0.0.6',
    author='blaze.zhang',
    author_email='blaze.zhang@cloudminds.com',
    url='https://src.cloudminds.com/ai-api/robotgpt-interpreter',
    description=u'robotgpt-interpreter',
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=['interpreter'],
    data_files=[
    ('bin',  ['bin/interpreter'])
    ],
    scripts=['bin/interpreter']
)


import sys
from .core.core import Interpreter

sys.modules["interpreter"] = Interpreter()

# ^ This is done so when users `import interpreter`,
# they get an instance.

# **This is a controversial thing to do,**
# because perhaps modules ought to behave like modules.

# But I think it saves a step, removes friction, and looks good.

#    ____      __                            __
#   /  _/___  / /____  _________  ________  / /____  _____
#   / // __ \/ __/ _ \/ ___/ __ \/ ___/ _ \/ __/ _ \/ ___/
# _/ // / / / /_/  __/ /  / /_/ / /  /  __/ /_/  __/ /
#  /___/_/ /_/\__/\___/_/  / .___/_/   \___/\__/\___/_/
#                       /_/
